def printList (the_list, level = 0):
    for each_list in the_list:
        if isinstance(each_list, list):#默认递归不能超过100
            printList(each_list, level + 1)
        else:
            for tab_stop in range(level):
                print("\t", end='')
            print(each_list)


from  distutils.core import setup
setup(
    name = 'testInstall',
    version = '1.1.0',
    py_modules = ['testInstall'],
    author = 'fanxinglanyu',
    author_mail = 'jinkang22@foxmail.com',
    description = '测试安装库'
)